==> libjgoodies-looks-java_2.4.1.orig.tar.gz: jgoodies-looks-2.4.1/src/test/com/jgoodies/looks/tests/OptionsTest.java <==
/*
 * Copyright (c) 2001-2011 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  o Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 *  o Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 *  o Neither the name of JGoodies Karsten Lentzsch nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.jgoodies.looks.tests;

import javax.swing.UIManager;

import junit.framework.TestCase;

import com.jgoodies.looks.LookUtils;
import com.jgoodies.looks.Options;

/**
 * A test case for class {@link Options}.
 *
 * @author	Karsten Lentzsch
 * @version $Revision: 1.7 $
 */
public final class OptionsTest extends TestCase {


    /**
     * Checks that tab icons can be enabled and disabled via the Options.
     */
    public void testTabIconsEnablement() {
        Boolean systemDefault = LookUtils.getBooleanSystemProperty(
                Options.TAB_ICONS_ENABLED_KEY,
                "Test: tab icons");

        if (systemDefault != null) {
            assertEquals("Tab icon enablement honors system property.",
                    systemDefault.booleanValue(),
                    Options.isTabIconsEnabled());
            return;
        }
        UIManager.put(Options.TAB_ICONS_ENABLED_KEY, null);
        assertTrue("Tab icons are enabled by default.", Options.isTabIconsEnabled());

        Options.setTabIconsEnabled(true);
        assertTrue("Tab icons are enabled.", Options.isTabIconsEnabled());

        Options.setTabIconsEnabled(false);
        assertFalse("Tab icons are disabled.", Options.isTabIconsEnabled());
    }


}

==> libjgoodies-looks-java_2.4.2.orig.tar.gz: jgoodies-looks-2.4.2/src/test/com/jgoodies/looks/tests/OptionsTest.java <==
/*
 * Copyright (c) 2001-2011 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  o Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 *  o Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 *  o Neither the name of JGoodies Karsten Lentzsch nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.jgoodies.looks.tests;

import javax.swing.UIManager;

import junit.framework.TestCase;

import com.jgoodies.looks.LookUtils;
import com.jgoodies.looks.Options;

/**
 * A test case for class {@link Options}.
 *
 * @author	Karsten Lentzsch
 * @version $Revision: 1.7 $
 */
public final class OptionsTest extends TestCase {


    /**
     * Checks that tab icons can be enabled and disabled via the Options.
     */
    public static void testTabIconsEnablement() {
        Boolean systemDefault = LookUtils.getBooleanSystemProperty(
                Options.TAB_ICONS_ENABLED_KEY,
                "Test: tab icons");

        if (systemDefault != null) {
            assertEquals("Tab icon enablement honors system property.",
                    systemDefault.booleanValue(),
                    Options.isTabIconsEnabled());
            return;
        }
        UIManager.put(Options.TAB_ICONS_ENABLED_KEY, null);
        assertTrue("Tab icons are enabled by default.", Options.isTabIconsEnabled());

        Options.setTabIconsEnabled(true);
        assertTrue("Tab icons are enabled.", Options.isTabIconsEnabled());

        Options.setTabIconsEnabled(false);
        assertFalse("Tab icons are disabled.", Options.isTabIconsEnabled());
    }


}
